chrome.tabs.query({ active: true, currentWindow: true }, function (tabs) {
  const url = 'extension ' + tabs[0].url;
  document.getElementById('url').textContent = tabs[0].url;

  // Progress bar elements
  const progressContainer = document.getElementById('progressContainer');
  const progressBar = document.getElementById('progressBar');
  
  let progressInterval;
  let currentProgress = 0;

  // Function to update progress smoothly
  function startProgress() {
    progressContainer.style.display = 'block';
    currentProgress = 0;
    progressBar.style.width = '0%';

    progressInterval = setInterval(() => {
      if (currentProgress < 90) {
        // Slower progress as we get closer to 90%
        const increment = (90 - currentProgress) / 30;
        currentProgress += Math.max(0.1, increment);
        progressBar.style.width = `${currentProgress}%`;
      }
    }, 100);
  }

  function completeProgress() {
    clearInterval(progressInterval);
    currentProgress = 100;
    progressBar.style.width = '100%';
    
    setTimeout(() => {
      progressContainer.style.display = 'none';
      progressBar.style.width = '0%';
    }, 500);
  }

  // Start progress animation
  startProgress();

  // Xóa chrome.storage.local trước khi gửi yêu cầu mới
  chrome.storage.local.clear(function() {
    console.log('Chrome storage has been reset.');

    // Gửi URL đến Flask server
    fetch('http://analysischess116.ddns.net:8000/message-extension', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify({ message: url }),
      credentials: 'same-origin'
    })
    .then(response => {
      if (!response.ok) {
        throw new Error(`HTTP error! Status: ${response.status}`);
      }
      return response.json();
    })
    .then(data => {
      completeProgress();

      // Lưu dữ liệu vào Chrome Storage
      chrome.storage.local.set({ serverResponse: data }, function() {
        // Kiểm tra giá trị data.message và hiển thị thông báo tương ứng
        const responseElement = document.getElementById('response');
        if (data.message === false) {
          responseElement.textContent = 'False';
          responseElement.style.color = 'red'; // Tùy chọn: đổi màu cho false
        } else {
          responseElement.textContent = 'Success';
          responseElement.style.color = 'green'; // Tùy chọn: đổi màu cho success
        }
        document.getElementById('error').textContent = '';
      });
    })

    .catch(error => {
      completeProgress();

      // Hiển thị lỗi nếu có
      document.getElementById('response').textContent = '';
      document.getElementById('error').textContent = `Error: ${error.message}`;
    });
  });
});